@@ -1,11 +1,14 @@
 import json
-import pkg_resources
+from uuid import UUID
 import django
 from django.db import models
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured, ValidationError
+from django_jsonform.utils import _get_django_version
 
-if pkg_resources.parse_version(django.get_version()) >= pkg_resources.parse_version("3.1"):
+django_major, django_minor = _get_django_version()
+
+if django_major > 3 or (django_major == 3 and django_minor >= 1):
     # Django >= 3.1
     from django.forms import JSONField as DjangoJSONFormField
 else:
@@ -72,6 +75,13 @@ class JSONFormField(DjangoJSONFormField):
         self.widget.add_error(error_map)
 
 
+class UUIDCompatibleEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, UUID):
+            return str(obj)
+        return json.JSONEncoder.default(self, obj)
+
+
 class ArrayFormField(SimpleArrayField):
     def __init__(self, base_field, **kwargs):
         if hasattr(SimpleArrayField, 'mock_field'):
@@ -93,7 +103,7 @@ class ArrayFormField(SimpleArrayField):
 
     def prepare_value(self, value):
         if isinstance(value, list):
-            return json.dumps(value)
+            return json.dumps(value, cls=UUIDCompatibleEncoder)
         return value
 
     def to_python(self, value):
@@ -118,4 +128,4 @@ class ArrayFormField(SimpleArrayField):
         if self.min_items:
             schema['min_items'] = self.min_items
 
-        return schema
\ No newline at end of file
+        return schema
