@@ -1,9 +1,11 @@
-import pkg_resources
 import django
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
+from django_jsonform.utils import _get_django_version
 
-if pkg_resources.parse_version(django.get_version()) >= pkg_resources.parse_version("3.1"):
+django_major, django_minor = _get_django_version()
+
+if django_major > 3 or (django_major == 3 and django_minor >= 1):
     # Django >= 3.1
     from django.db.models import JSONField as DjangoJSONField
 else:
