@@ -1,9 +1,18 @@
+SECRET_KEY = "secret for test"
+
 ROOT_URLCONF='django_jsonform.urls'
 
 INSTALLED_APPS=[
     'django_jsonform',
 ]
 
+DATABASES = {
+    'default': {
+        'ENGINE': 'django.db.backends.sqlite3',
+        'NAME': ":memory:",
+    },
+}
+
 TEMPLATES = [
     {
         'BACKEND': 'django.template.backends.django.DjangoTemplates',
